@@ -13,10 +13,10 @@ class TestData:
     test_full_name: str
     test_full_path: str
     test_status: ExecutionStatus = ExecutionStatus.COLLECTED
-    test_parameters: Optional[dict] = None
+    test_parameters: Optional[dict[str, str]] = None
     test_markers: Optional[list] = None
     test_start_time: Optional[str] = None
     test_end_time: Optional[str] = None
-    test_duration_sec: Optional[float] = None
+    test_duration_sec: Optional[float] = None  # only for the tst itself, not including fixtures
     exception_message: Optional[str] = None
     run_index: Optional[int] = None
