@@ -1,8 +1,12 @@
 import json
+import logging
 from dataclasses import is_dataclass
+from datetime import datetime, date, time
+from decimal import Decimal
 from enum import Enum, StrEnum
 from pathlib import Path
 
+logger = logging.getLogger('pytest_plugins.utils')
 
 def get_project_root(marker: str = ".git") -> Path | None:
     path = Path(__file__).resolve()
@@ -12,14 +16,26 @@ def get_project_root(marker: str = ".git") -> Path | None:
     return None
 
 
-def serialize_data(obj):
-    if isinstance(obj, (Enum, StrEnum)):
-        return obj.value
-    if is_dataclass(obj):
+def serialize_data(obj: object) -> object:  # default_serialize
+    if isinstance(obj, type):
+        return obj.__name__
+    if is_dataclass(obj) and not isinstance(obj, type):
         return obj.__dict__
+    if isinstance(obj, Enum):
+        return obj.value
+    if isinstance(obj, set):
+        return list(obj)
+    if isinstance(obj, tuple):
+        return list(obj)
+    if isinstance(obj, (datetime, date, time)):
+        return obj.isoformat()
+    if isinstance(obj, Decimal):
+        return float(obj)
+    if isinstance(obj, Path):
+        return str(obj)
+    logger.error(f'Object is not serializable: {obj}')
     raise TypeError(f"Type {type(obj)} not serializable")
 
-
 def open_json(path: Path) -> dict:
     with open(path, 'r', encoding='utf-8') as json_file:
         return json.load(json_file)
