@@ -1,7 +1,10 @@
+import json
 import logging
 
 from _pytest.python import Function
 
+from pytest_plugins.utils.helper import serialize_data
+
 logger = logging.getLogger()
 
 
@@ -30,3 +33,14 @@ def get_test_full_path(item: Function) -> str:
     """Get the full name of the test, including parameters if available."""
     test_name = get_test_path_without_parameters(item=item)
     return f"{test_name}[{item.callspec.params}]" if getattr(item, 'callspec', None) else test_name
+
+
+def log_test_results(item: Function, test_results: dict) -> None:
+    if not getattr(item.config, '_better_report_enabled', None):
+        return
+
+    test_full_name = get_test_full_name(item=item)
+    if test_full_name in test_results:
+        logger.debug(f'Test Results: \n{json.dumps(test_results[test_full_name], indent=4, default=serialize_data)}')
+    else:
+        logger.warning(f"Test {test_full_name} missing in test_results during report")
